@@ -102,7 +102,8 @@ class Drive(base.ResourceBase):
                 parameter='state', value=state,
                 valid_values=' ,'.join(i.value for i in res_cons.IndicatorLED))
 
+        etag = self._get_etag()
         data = {'IndicatorLED': state}
 
-        self._conn.patch(self.path, data=data)
+        self._conn.patch(self.path, data=data, etag=etag)
         self.invalidate()
