@@ -59,7 +59,7 @@ class TaskService(base.ResourceBase):
             used in any resource that needs registries to parse messages
         :param root: Sushy root object. Empty for Sushy root itself.
         """
-        super(TaskService, self).__init__(
+        super().__init__(
             connector, identity, redfish_version=redfish_version,
             registries=registries, root=root)
 
